# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.group.v1 import tx_pb2 as cosmos_dot_group_dot_v1_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/group/v1/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class MsgStub(object):
    """Msg is the cosmos.group.v1 Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateGroup = channel.unary_unary(
                '/cosmos.group.v1.Msg/CreateGroup',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroup.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupResponse.FromString,
                _registered_method=True)
        self.UpdateGroupMembers = channel.unary_unary(
                '/cosmos.group.v1.Msg/UpdateGroupMembers',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMembers.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMembersResponse.FromString,
                _registered_method=True)
        self.UpdateGroupAdmin = channel.unary_unary(
                '/cosmos.group.v1.Msg/UpdateGroupAdmin',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupAdmin.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupAdminResponse.FromString,
                _registered_method=True)
        self.UpdateGroupMetadata = channel.unary_unary(
                '/cosmos.group.v1.Msg/UpdateGroupMetadata',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMetadata.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMetadataResponse.FromString,
                _registered_method=True)
        self.CreateGroupPolicy = channel.unary_unary(
                '/cosmos.group.v1.Msg/CreateGroupPolicy',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupPolicy.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupPolicyResponse.FromString,
                _registered_method=True)
        self.CreateGroupWithPolicy = channel.unary_unary(
                '/cosmos.group.v1.Msg/CreateGroupWithPolicy',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupWithPolicy.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupWithPolicyResponse.FromString,
                _registered_method=True)
        self.UpdateGroupPolicyAdmin = channel.unary_unary(
                '/cosmos.group.v1.Msg/UpdateGroupPolicyAdmin',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyAdmin.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyAdminResponse.FromString,
                _registered_method=True)
        self.UpdateGroupPolicyDecisionPolicy = channel.unary_unary(
                '/cosmos.group.v1.Msg/UpdateGroupPolicyDecisionPolicy',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyDecisionPolicy.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyDecisionPolicyResponse.FromString,
                _registered_method=True)
        self.UpdateGroupPolicyMetadata = channel.unary_unary(
                '/cosmos.group.v1.Msg/UpdateGroupPolicyMetadata',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyMetadata.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyMetadataResponse.FromString,
                _registered_method=True)
        self.SubmitProposal = channel.unary_unary(
                '/cosmos.group.v1.Msg/SubmitProposal',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgSubmitProposal.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgSubmitProposalResponse.FromString,
                _registered_method=True)
        self.WithdrawProposal = channel.unary_unary(
                '/cosmos.group.v1.Msg/WithdrawProposal',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgWithdrawProposal.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgWithdrawProposalResponse.FromString,
                _registered_method=True)
        self.Vote = channel.unary_unary(
                '/cosmos.group.v1.Msg/Vote',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgVote.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgVoteResponse.FromString,
                _registered_method=True)
        self.Exec = channel.unary_unary(
                '/cosmos.group.v1.Msg/Exec',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgExec.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgExecResponse.FromString,
                _registered_method=True)
        self.LeaveGroup = channel.unary_unary(
                '/cosmos.group.v1.Msg/LeaveGroup',
                request_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgLeaveGroup.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgLeaveGroupResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg is the cosmos.group.v1 Msg service.
    """

    def CreateGroup(self, request, context):
        """CreateGroup creates a new group with an admin account address, a list of members and some optional metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroupMembers(self, request, context):
        """UpdateGroupMembers updates the group members with given group id and admin address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroupAdmin(self, request, context):
        """UpdateGroupAdmin updates the group admin with given group id and previous admin address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroupMetadata(self, request, context):
        """UpdateGroupMetadata updates the group metadata with given group id and admin address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGroupPolicy(self, request, context):
        """CreateGroupPolicy creates a new group policy using given DecisionPolicy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGroupWithPolicy(self, request, context):
        """CreateGroupWithPolicy creates a new group with policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroupPolicyAdmin(self, request, context):
        """UpdateGroupPolicyAdmin updates a group policy admin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroupPolicyDecisionPolicy(self, request, context):
        """UpdateGroupPolicyDecisionPolicy allows a group policy's decision policy to be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroupPolicyMetadata(self, request, context):
        """UpdateGroupPolicyMetadata updates a group policy metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitProposal(self, request, context):
        """SubmitProposal submits a new proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawProposal(self, request, context):
        """WithdrawProposal withdraws a proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vote(self, request, context):
        """Vote allows a voter to vote on a proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exec(self, request, context):
        """Exec executes a proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LeaveGroup(self, request, context):
        """LeaveGroup allows a group member to leave the group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroup,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroup.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupResponse.SerializeToString,
            ),
            'UpdateGroupMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroupMembers,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMembers.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMembersResponse.SerializeToString,
            ),
            'UpdateGroupAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroupAdmin,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupAdmin.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupAdminResponse.SerializeToString,
            ),
            'UpdateGroupMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroupMetadata,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMetadata.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMetadataResponse.SerializeToString,
            ),
            'CreateGroupPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroupPolicy,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupPolicy.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupPolicyResponse.SerializeToString,
            ),
            'CreateGroupWithPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroupWithPolicy,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupWithPolicy.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupWithPolicyResponse.SerializeToString,
            ),
            'UpdateGroupPolicyAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroupPolicyAdmin,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyAdmin.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyAdminResponse.SerializeToString,
            ),
            'UpdateGroupPolicyDecisionPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroupPolicyDecisionPolicy,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyDecisionPolicy.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyDecisionPolicyResponse.SerializeToString,
            ),
            'UpdateGroupPolicyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroupPolicyMetadata,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyMetadata.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyMetadataResponse.SerializeToString,
            ),
            'SubmitProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitProposal,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgSubmitProposal.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgSubmitProposalResponse.SerializeToString,
            ),
            'WithdrawProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawProposal,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgWithdrawProposal.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgWithdrawProposalResponse.SerializeToString,
            ),
            'Vote': grpc.unary_unary_rpc_method_handler(
                    servicer.Vote,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgVote.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgVoteResponse.SerializeToString,
            ),
            'Exec': grpc.unary_unary_rpc_method_handler(
                    servicer.Exec,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgExec.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgExecResponse.SerializeToString,
            ),
            'LeaveGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.LeaveGroup,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgLeaveGroup.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_tx__pb2.MsgLeaveGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.group.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.group.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg is the cosmos.group.v1 Msg service.
    """

    @staticmethod
    def CreateGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/CreateGroup',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroup.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroupMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/UpdateGroupMembers',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMembers.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMembersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroupAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/UpdateGroupAdmin',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupAdmin.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroupMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/UpdateGroupMetadata',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMetadata.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateGroupPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/CreateGroupPolicy',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupPolicy.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupPolicyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateGroupWithPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/CreateGroupWithPolicy',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupWithPolicy.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgCreateGroupWithPolicyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroupPolicyAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/UpdateGroupPolicyAdmin',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyAdmin.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroupPolicyDecisionPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/UpdateGroupPolicyDecisionPolicy',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyDecisionPolicy.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyDecisionPolicyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroupPolicyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/UpdateGroupPolicyMetadata',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyMetadata.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgUpdateGroupPolicyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/SubmitProposal',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgSubmitProposal.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgSubmitProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/WithdrawProposal',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgWithdrawProposal.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgWithdrawProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Vote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/Vote',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgVote.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgVoteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Exec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/Exec',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgExec.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgExecResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LeaveGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Msg/LeaveGroup',
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgLeaveGroup.SerializeToString,
            cosmos_dot_group_dot_v1_dot_tx__pb2.MsgLeaveGroupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/circuit/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.cosmos.circuit.v1 import types_pb2 as cosmos_dot_circuit_dot_v1_dot_types__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/circuit/v1/query.proto\x12\x11\x63osmos.circuit.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1d\x63osmos/circuit/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x63osmos/query/v1/query.proto\"&\n\x13QueryAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"E\n\x0f\x41\x63\x63ountResponse\x12\x32\n\npermission\x18\x01 \x01(\x0b\x32\x1e.cosmos.circuit.v1.Permissions\"R\n\x14QueryAccountsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8f\x01\n\x10\x41\x63\x63ountsResponse\x12>\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32,.cosmos.circuit.v1.GenesisAccountPermissions\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x1a\n\x18QueryDisabledListRequest\"-\n\x14\x44isabledListResponse\x12\x15\n\rdisabled_list\x18\x01 \x03(\t2\xad\x03\n\x05Query\x12\x89\x01\n\x07\x41\x63\x63ount\x12&.cosmos.circuit.v1.QueryAccountRequest\x1a\".cosmos.circuit.v1.AccountResponse\"2\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\'\x12%/cosmos/circuit/v1/accounts/{address}\x12\x82\x01\n\x08\x41\x63\x63ounts\x12\'.cosmos.circuit.v1.QueryAccountsRequest\x1a#.cosmos.circuit.v1.AccountsResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/circuit/v1/accounts\x12\x92\x01\n\x0c\x44isabledList\x12+.cosmos.circuit.v1.QueryDisabledListRequest\x1a\'.cosmos.circuit.v1.DisabledListResponse\",\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02!\x12\x1f/cosmos/circuit/v1/disable_listB\x1eZ\x1c\x63osmossdk.io/x/circuit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.circuit.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034cosmossdk.io/x/circuit/types'
  _globals['_QUERY'].methods_by_name['Account']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Account']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\'\022%/cosmos/circuit/v1/accounts/{address}'
  _globals['_QUERY'].methods_by_name['Accounts']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Accounts']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/circuit/v1/accounts'
  _globals['_QUERY'].methods_by_name['DisabledList']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DisabledList']._serialized_options = b'\210\347\260*\001\202\323\344\223\002!\022\037/cosmos/circuit/v1/disable_list'
  _globals['_QUERYACCOUNTREQUEST']._serialized_start=186
  _globals['_QUERYACCOUNTREQUEST']._serialized_end=224
  _globals['_ACCOUNTRESPONSE']._serialized_start=226
  _globals['_ACCOUNTRESPONSE']._serialized_end=295
  _globals['_QUERYACCOUNTSREQUEST']._serialized_start=297
  _globals['_QUERYACCOUNTSREQUEST']._serialized_end=379
  _globals['_ACCOUNTSRESPONSE']._serialized_start=382
  _globals['_ACCOUNTSRESPONSE']._serialized_end=525
  _globals['_QUERYDISABLEDLISTREQUEST']._serialized_start=527
  _globals['_QUERYDISABLEDLISTREQUEST']._serialized_end=553
  _globals['_DISABLEDLISTRESPONSE']._serialized_start=555
  _globals['_DISABLEDLISTRESPONSE']._serialized_end=600
  _globals['_QUERY']._serialized_start=603
  _globals['_QUERY']._serialized_end=1032
# @@protoc_insertion_point(module_scope)



from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as _clob_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RedisOrder(_message.Message):
    __slots__ = ("id", "order", "ticker", "ticker_type", "price", "size")
    class TickerType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TICKER_TYPE_UNSPECIFIED: _ClassVar[RedisOrder.TickerType]
        TICKER_TYPE_PERPETUAL: _ClassVar[RedisOrder.TickerType]
        TICKER_TYPE_SPOT: _ClassVar[RedisOrder.TickerType]
    TICKER_TYPE_UNSPECIFIED: RedisOrder.TickerType
    TICKER_TYPE_PERPETUAL: RedisOrder.TickerType
    TICKER_TYPE_SPOT: RedisOrder.TickerType
    ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    TICKER_TYPE_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    id: str
    order: _clob_pb2.IndexerOrder
    ticker: str
    ticker_type: RedisOrder.TickerType
    price: str
    size: str
    def __init__(self, id: _Optional[str] = ..., order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ..., ticker: _Optional[str] = ..., ticker_type: _Optional[_Union[RedisOrder.TickerType, str]] = ..., price: _Optional[str] = ..., size: _Optional[str] = ...) -> None: ...



from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as _vest_entry_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryVestEntryRequest(_message.Message):
    __slots__ = ("vester_account",)
    VESTER_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    vester_account: str
    def __init__(self, vester_account: _Optional[str] = ...) -> None: ...

class QueryVestEntryResponse(_message.Message):
    __slots__ = ("entry",)
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: _vest_entry_pb2.VestEntry
    def __init__(self, entry: _Optional[_Union[_vest_entry_pb2.VestEntry, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/libs/bits/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/libs/bits/types.proto\x12\x14tendermint.libs.bits\"\'\n\x08\x42itArray\x12\x0c\n\x04\x62its\x18\x01 \x01(\x03\x12\r\n\x05\x65lems\x18\x02 \x03(\x04\x42\x39Z7github.com/cometbft/cometbft/proto/tendermint/libs/bitsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.libs.bits.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/cometbft/cometbft/proto/tendermint/libs/bits'
  _globals['_BITARRAY']._serialized_start=58
  _globals['_BITARRAY']._serialized_end=97
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/group/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.group.v1 import types_pb2 as cosmos_dot_group_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/group/v1/events.proto\x12\x0f\x63osmos.group.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/group/v1/types.proto\"$\n\x10\x45ventCreateGroup\x12\x10\n\x08group_id\x18\x01 \x01(\x04\"$\n\x10\x45ventUpdateGroup\x12\x10\n\x08group_id\x18\x01 \x01(\x04\"C\n\x16\x45ventCreateGroupPolicy\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"C\n\x16\x45ventUpdateGroupPolicy\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"*\n\x13\x45ventSubmitProposal\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\",\n\x15\x45ventWithdrawProposal\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\" \n\tEventVote\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"g\n\tEventExec\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\x37\n\x06result\x18\x02 \x01(\x0e\x32\'.cosmos.group.v1.ProposalExecutorResult\x12\x0c\n\x04logs\x18\x03 \x01(\t\"N\n\x0f\x45ventLeaveGroup\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12)\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x8f\x01\n\x13\x45ventProposalPruned\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.cosmos.group.v1.ProposalStatus\x12\x32\n\x0ctally_result\x18\x03 \x01(\x0b\x32\x1c.cosmos.group.v1.TallyResultB&Z$github.com/cosmos/cosmos-sdk/x/groupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/group'
  _globals['_EVENTCREATEGROUPPOLICY'].fields_by_name['address']._loaded_options = None
  _globals['_EVENTCREATEGROUPPOLICY'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTUPDATEGROUPPOLICY'].fields_by_name['address']._loaded_options = None
  _globals['_EVENTUPDATEGROUPPOLICY'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTLEAVEGROUP'].fields_by_name['address']._loaded_options = None
  _globals['_EVENTLEAVEGROUP'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEGROUP']._serialized_start=105
  _globals['_EVENTCREATEGROUP']._serialized_end=141
  _globals['_EVENTUPDATEGROUP']._serialized_start=143
  _globals['_EVENTUPDATEGROUP']._serialized_end=179
  _globals['_EVENTCREATEGROUPPOLICY']._serialized_start=181
  _globals['_EVENTCREATEGROUPPOLICY']._serialized_end=248
  _globals['_EVENTUPDATEGROUPPOLICY']._serialized_start=250
  _globals['_EVENTUPDATEGROUPPOLICY']._serialized_end=317
  _globals['_EVENTSUBMITPROPOSAL']._serialized_start=319
  _globals['_EVENTSUBMITPROPOSAL']._serialized_end=361
  _globals['_EVENTWITHDRAWPROPOSAL']._serialized_start=363
  _globals['_EVENTWITHDRAWPROPOSAL']._serialized_end=407
  _globals['_EVENTVOTE']._serialized_start=409
  _globals['_EVENTVOTE']._serialized_end=441
  _globals['_EVENTEXEC']._serialized_start=443
  _globals['_EVENTEXEC']._serialized_end=546
  _globals['_EVENTLEAVEGROUP']._serialized_start=548
  _globals['_EVENTLEAVEGROUP']._serialized_end=626
  _globals['_EVENTPROPOSALPRUNED']._serialized_start=629
  _globals['_EVENTPROPOSALPRUNED']._serialized_end=772
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/blocktime/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.blocktime import blocktime_pb2 as dydxprotocol_dot_blocktime_dot_blocktime__pb2
from v4_proto.dydxprotocol.blocktime import params_pb2 as dydxprotocol_dot_blocktime_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/blocktime/query.proto\x12\x16\x64ydxprotocol.blocktime\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a&dydxprotocol/blocktime/blocktime.proto\x1a#dydxprotocol/blocktime/params.proto\"\x1c\n\x1aQueryDowntimeParamsRequest\"[\n\x1bQueryDowntimeParamsResponse\x12<\n\x06params\x18\x01 \x01(\x0b\x32&.dydxprotocol.blocktime.DowntimeParamsB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dQueryPreviousBlockInfoRequest\"Q\n\x1eQueryPreviousBlockInfoResponse\x12/\n\x04info\x18\x01 \x01(\x0b\x32!.dydxprotocol.blocktime.BlockInfo\"\x1d\n\x1bQueryAllDowntimeInfoRequest\"U\n\x1cQueryAllDowntimeInfoResponse\x12\x35\n\x04info\x18\x01 \x01(\x0b\x32\'.dydxprotocol.blocktime.AllDowntimeInfo2\xf1\x03\n\x05Query\x12\xad\x01\n\x0e\x44owntimeParams\x12\x32.dydxprotocol.blocktime.QueryDowntimeParamsRequest\x1a\x33.dydxprotocol.blocktime.QueryDowntimeParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/v4/blocktime/downtime_params\x12\x82\x01\n\x11PreviousBlockInfo\x12\x35.dydxprotocol.blocktime.QueryPreviousBlockInfoRequest\x1a\x36.dydxprotocol.blocktime.QueryPreviousBlockInfoResponse\x12\xb2\x01\n\x0f\x41llDowntimeInfo\x12\x33.dydxprotocol.blocktime.QueryAllDowntimeInfoRequest\x1a\x34.dydxprotocol.blocktime.QueryAllDowntimeInfoResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/v4/blocktime/all_downtime_infoB=Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.blocktime.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/types'
  _globals['_QUERYDOWNTIMEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYDOWNTIMEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['DowntimeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DowntimeParams']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/v4/blocktime/downtime_params'
  _globals['_QUERY'].methods_by_name['AllDowntimeInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllDowntimeInfo']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/v4/blocktime/all_downtime_info'
  _globals['_QUERYDOWNTIMEPARAMSREQUEST']._serialized_start=191
  _globals['_QUERYDOWNTIMEPARAMSREQUEST']._serialized_end=219
  _globals['_QUERYDOWNTIMEPARAMSRESPONSE']._serialized_start=221
  _globals['_QUERYDOWNTIMEPARAMSRESPONSE']._serialized_end=312
  _globals['_QUERYPREVIOUSBLOCKINFOREQUEST']._serialized_start=314
  _globals['_QUERYPREVIOUSBLOCKINFOREQUEST']._serialized_end=345
  _globals['_QUERYPREVIOUSBLOCKINFORESPONSE']._serialized_start=347
  _globals['_QUERYPREVIOUSBLOCKINFORESPONSE']._serialized_end=428
  _globals['_QUERYALLDOWNTIMEINFOREQUEST']._serialized_start=430
  _globals['_QUERYALLDOWNTIMEINFOREQUEST']._serialized_end=459
  _globals['_QUERYALLDOWNTIMEINFORESPONSE']._serialized_start=461
  _globals['_QUERYALLDOWNTIMEINFORESPONSE']._serialized_end=546
  _globals['_QUERY']._serialized_start=549
  _globals['_QUERY']._serialized_end=1046
# @@protoc_insertion_point(module_scope)
